@@ -1,8 +1,8 @@
 `capwords` <-
-function(x) {
+function(x, special.words = c("ELA", "II", "III", "IV", "EMH", "HS", "MS", "ES", "SES", "IEP", "ELL", "MAD", "SD", "US", "SGP")) {
 	if (is.null(x)) return(NULL)
 	x <- gsub("_", " ", x)
-	special.words <- c("ELA", "II", "III", "IV", "EMH", "HS", "MS", "ES", "SES", "IEP", "ELL", "MAD", "SD", "US")
+	x <- gsub("[.]", " ", x)
 	my.split <- function(words, split.character) {
 		tmp.split <- unlist(strsplit(words, split=split.character))
 		tmp.split.special.words.index <- which(!tmp.split %in% special.words)
